
************************************************************************************************************************************************************************************************
** Set directories
************************************************************************************************************************************************************************************************

* define the folder of the replication files as the stata directory *
* using the syntax in line 9 *

global Alt_facts_replication_directory "~/Dropbox/Propaganda/replication_final/"

foreach path in  $Alt_facts_replication_directory  {
	capture cd "`path'"
	if _rc == 0 macro def path `path'
	}

cd ${path}

global tables "${path}/results/tables"
global figures "${path}/results/figures"
set more off 
 
*****************************************************************************************************
** Use original data
*****************************************************************************************************

use data/GEF_dataset_final, clear /** Note this is original survey. The labels for the variables in this file are generated by: ~/Dropbox/Propaganda/data/do_files/labels_final.do */


** Keep only born in France
	keep if birth_place==1	
	
*****************************************************************************************************
** Generate and vabel variables for the analysis
*****************************************************************************************************
	
quietly{

		
**gen dummy variables for being right in the test
	gen dtest_refug_men= (test_refug_men== 6)
	gen dtest_french_2ww= (test_french_2ww==3)
	gen dtest_labour_mig15= (test_labour_mig15==5)
	gen dtest_chance_dictator= (test_chance_dictator==2)
	gen dtest_exopinion = (opinion_unemp==2)
	
	label var dtest_refug_men "1 if right in the test share men refugee"
	label var dtest_french_2ww "1 if right in the test share french migration in the 2WW"
	label var dtest_labour_mig15 "1 if right in the test share labour migration"
	label var dtest_chance_dictator "1 if right in the test chances dictator game"
	label var dtest_exopinion "1 if right in the test opinion before the treatment"
	
	
** Create another outcome var 1 if transfer more in the second dictator game
	gen dictator_out = (dictator_2>dictator_1)	
	label var dictator_out "1 if higher transfer in the second dictator game"
	
** Create a dummy variable 1 if is at least likely to vote by the FN
	gen dwillvote_FN = (inlist(willvote_FN , 4, 5))
	label var dwillvote_FN "1 if at least likely to vote for FN"

	gen ddisaggree_FN = (inlist(disagree_FN, 3, 4 ))
	label var ddisaggree_FN "1 if at least disagree to vote for FN"

*** Gen a var being right in the test
	gen test_accu = dtest_refug_men+dtest_french_2ww+dtest_labour_mig15
	label var test_accu "Number of test that are right from 0-3"
	
**Voted by MLP in the previoius presidentials		
	gen voted_MLP = (whomvoted_past==4)
	label var voted_MLP "1 if voted by MPL in the previous presidentials"
	
***dummy if married and single
	gen dmarried= (marital_status==2)	
	label var dmarried "1 if married"
	
	gen dsingle = (marital_status==1)
	label var dsingle "1 if single"

** Dummy if own their own house
	gen dland_owner = (property==1)
	label var dland_owner "1 if land onwer"

** Employment status
	gen dunemployed= (labor_stat==6)
	label var dunemployed "1 if unemployed"
	
	gen dretired = (labor_stat==7)
	label var dretired "1 if retired or pre retired"
	
	gen dstudent = (labor_stat==5)
	label var dstudent "1 if student"
	
	gen dworker = (inlist(labor_stat, 1, 2))
	label var dworker "1 if full or part time worker"
	
	gen dhome= (labor_stat==8)
	label var dhome "1 if hosue wife/husband"
	
** Source of media
	gen dtelevision = (source_media==1)
	label var dtelevision "1 if source of media is television"
	
	gen dradio =(source_media==2)
	label var dradio "1 if source of media is Radio"
	
	gen dinternet = (source_media==3)
	label var dinternet "1 if source of media is internet"
	
** Source of income
	gen dwage = (source_inc==1)
	label var dwage "1 source of income is wage"
	
	gen dbenefits = (inlist(source_inc, 2,4))
	label var dbenefits "1 source of income any social benefit"

	gen dpension = (source_inc== 3)
	label var dpension "1 source of income is retired pension"

** D religion
	gen dcatholic= (religion==1)
	label var dcatholic "1 if religion is catholic"
	
	gen dmuslim= (religion==4)
	label var dmuslim "1 if religion is Muslim"
	
	gen dnorelig= (religion==7)
	label var dnorelig "1 if NO religion"

** Dummy education 
	gen high_educ=(education>=6)
	label var high_educ "1 if  education is >=6"

	
** Dummy trust on institutions
	gen dtrust_INSEE = (inlist(trust_INSEE, 1 , 2))	
	gen dtrust_UN = (inlist(trust_UN, 1 , 2))	
	gen dtrust_ministryeco = (inlist(trust_ministryeco, 1 , 2))	
	gen dtrust_OCDE = (inlist(trust_OCDE, 1, 2))		

	label var dtrust_INSEE "1 if turst INSEE"
	label var dtrust_UN "1 if turst UN"
	label var dtrust_ministryeco "1 if turst Ministery of Economics"
	label var dtrust_OCDE "1 if turst OCDE"

	
	gen dtrustbcoup_INSEE = (trust_INSEE==1)	
	gen dtrustbcoup_UN = (trust_UN==1 )
	gen dtrustbcoup_ministryeco = (trust_ministryeco==1 )
	gen dtrustbcoup_OCDE = (trust_OCDE==1)

	label var dtrustbcoup_INSEE "1 if turst very much on INSEE"
	label var dtrustbcoup_UN "1 if turst very  much on UN"
	label var dtrustbcoup_ministryeco "1 if turst very much Ministery of Economics"
	label var dtrustbcoup_OCDE "1 if turst very much OCDE"

	
	
** Var for left right position
	gen left_right= 0
	replace left_right = 1 if (left_right_axis>=-2 & left_right_axis<=2 )
	replace left_right = 2 if (left_right_axis>2 )
	
	label define lr 0 "Left" 1 "Center" 2 "Right"
	label value left_right lr	
	
	gen village=(villa_size<3)
	label var village "Village"
	label var high_educ "High_educ"
	label var voted_MLP "Voted MLP"
	label var voted_FN "Voted FN"
	label var left_right "0 left, 1 center, 2 right"
				
** rural 
gen rural=1
replace rural=0 if villa_size==3

** use correct age quota 
drop quota_age 
rename quot_age quota_age

** generate distances to correct ancers
 
gen distance_correct_prior_unemp=abs(opinion_unemp-2)
gen parent_immigrant= (country_father!=.|country_mother!=. )
gen distance_correct_refug_men=abs(test_refug_men -6)
gen distance_correct_labour_mig=abs(test_labour_mig15 -5)
gen distance_french_2ww=abs(test_french_2ww -3)

** education dummies

gen low_educ=1-high_educ
gen HIGHER_educ=(education>7)

label var HIGHER_educ "Higher education"
label var high_educ "Secondary education" 
label var test_refug_men "(Posterior) knowledge about \% men-refugees"
label var test_labour_mig15 "(Posterior) knowledge about \% working migrants"

** treatment dummies

gen MLP=(treatment==1)
gen Info=(treatment==2)
gen Both=(treatment==3)
gen Control=(treatment==0)

gen InfoAndBoth=(treatment==2 | treatment==3)
gen MLPAndBoth=(treatment==1 | treatment==3)


label var MLP  "Alt-facts"
label var Info "Facts"
label var Both "Fact-Check"
label var disagree_FN "Disagree MLP, 4 cat"
label var ddis "Disagree with MLP's immigration policy"


label define treatments 0 "Control" 1 "Alt-Facts" 2 "Facts" 3 "Fact-Check"
label define treatments_for_incorrect 0 "Control for incorrect prior" 1 "Alt-Facts for incorrect prior" 2 "Facts for incorrect prior" 3 "Fact-Check for incorrect prior"
label values treatment treatments

*** agree with MLP on immigration

gen agree_immigr=1-ddis
label var agree_immigr "Agree with MLP's immigration policy"

gen strongly_agree_immigr=(disagree_FN==1)
label var strongly_agree_immigr "Strongly agree with MLP's immigration policy"


*** generate correct  and incorrect dummies
gen correct=(opinion_unemp <4)
gen incorrect=1-correct

** generate list variables
gen list_number=list1
replace list_number=list2 if list_number==.
gen list_with_MLP=1 if list2!=.
replace list_with_MLP=0 if list1!=.
gen list_zero=(list_number==0)
gen list_non_zero=(list_number>0)  
  
label var distance_correct_refug_men  "Dist. truth ref. men"
label var distance_correct_labour_mig "Dist. truth mig. work"
label var distance_french_2ww "Dist truth French ref. WWII"
 
label var dtest_refug_men   "Right ref. men"
label var  dtest_labour_mig "Right mig. work"
label var dtest_french_2ww  "Right French ref. WWII"
 
 gen reason_migration_economic=(reason_mig==1)
 
gen d_prior=(distance_correct_prior_unemp==0)
gen d_prior1=(distance_correct_prior_unemp==0|distance_correct_prior_unemp==1)
gen believe_MLP_refug_men=(test_refug_men==10)

gen reason_migration_security=(reason_mig==2)
gen reason_migration_not_security=1-reason_migration_security

gen intent_vote_FN=(willvote_FN>2)

gen main_religion=(religion!=2&religion!=3&religion!=4&religion!=5&religion!=6)

gen intent_vote_FN_probable=( willvote_FN>3)
gen intent_vote_FN_tres_probable=( willvote_FN>4)
gen intent_vote_FN_tres_improbable=(willvote_FN==2)


foreach var in trust_IN trust_UN trust_minist trust_OCDE{
recode `var' (5=3) (3=4) (4=5),  gen(R`var')
}

gen d_trust_INSEE=(trust_IN==1 )
gen d_trust_UN=(trust_UN==1 )
gen d_trust_inst=(trust_IN==1 ) | (trust_UN==1 )
gen degree_trust_UN_INSEE=(10-Rtrust_IN-Rtrust_UN)/10 /* if trust_IN!=5&trust_UN!=5  */
gen degree_trust_all_inst=(20-Rtrust_IN-Rtrust_UN-Rtrust_minist-Rtrust_OCDE)/20  /* if trust_IN!=5&trust_UN!=5&trust_minist!=5&trust_OCDE!=5 */
gen d_trust_inst_AND=(trust_IN==1 |trust_IN==2) & (trust_UN==1 |trust_UN==2)
gen d_mistrust_inst=1- d_trust_inst

foreach var in trust_IN trust_UN trust_minist trust_OCDE{
gen dummy_dis`var'=(`var'==4|`var'==3|`var'==5)
}

gen degree_distrust_UN_INSEE=(dummy_distrust_UN+ dummy_distrust_IN)/2
gen degree_distrust_all_inst=(dummy_distrust_IN+dummy_distrust_UN+dummy_distrust_minist+dummy_distrust_OCDE)/4

label var degree_trust_all_inst "Trust UN,INSEE,OECD,MinEcon"
label var degree_trust_UN_INSEE "Trust UN, INSEE"
label var d_trust_inst_AND "Trust UN, INSEE, dummy"
label var d_trust_UN "Trust UN, dummy"
label var d_trust_INSEE "Trust INSEE, dummy"

label var  degree_distrust_UN_INSEE "Av.Distrust UN,INSEE"
label var  degree_distrust_all_inst "Av.Distrust UN,INSEE,OECD,MinEcon"
 
gen willvoteMLP=(willvote_FN>3) 

label var willvote_FN "Will vote FN"
label var willvoteMLP "Will vote MLP"
label var list_number   "List number"
label var list_with_MLP "List w/ MLP"
label var dictator_out "Higher transfer to MLP"
label var reason_migration_economic "Reason for migration: Economic"
label var disagree_FN "Disagree FN"
label var low_educ    "Low education"
label var correct     "Correct prior"
label var incorrect   "Incorrect"

egen mean_quota_educ=mean(quota_educ)
egen mean_quota_age=mean(quota_age)
gen demean_quota_educ=quota_educ-mean_quota_educ
gen demean_quota_age=quota_age-mean_quota_age

foreach var in MLP Info Both {
egen mean_`var'=mean(`var')
gen dm`var'=`var'-mean_`var'
}

gen test_refug_men_MLP=(test_refug_men-6.656863)*MLP
gen opinion_unemp_MLP=(opinion_unemp-3.582516)*MLP
gen opinion_unemp_Both=opinion_unemp*Both
gen test_refug_men_Both=test_refug_men*Both
gen test_refug_men_Info=test_refug_men*Info
gen opinion_unemp_Info=opinion_unemp*Info
gen test_labour_mig15_MLP=(test_labour_mig15-3.582516)*MLP
gen posterior_unemp=1-(test_labour_mig15/(test_refug_men*0.5+5))
gen posterior_unemp_MLP=(posterior_unemp- .5020674)*MLP

label var opinion_unemp  "Prior migr. unempl"
label var opinion_unemp_MLP  "Prior migr. unempl X Alt-Facts"
label var posterior_unemp  "Posterior migr. unempl."
label var opinion_unemp_MLP  "Posterior migr. unempl. X Alt-Facts"
label var test_refug_men_MLP "Refugee men X Alt-Facts"

gen not_give_MLP_give_others=(dictator_2==0&dictator_1>0)

gen not_give_MLP=(dictator_2==0)
gen give_MLP_do_not_give_others=(dictator_2>1&dictator_1==0)
gen give_MLP_more=(dictator_2>=dictator_1)
gen give_MLP_strictly_more=(dictator_2>dictator_1)
gen give_MLP_strictly_less=(dictator_2<dictator_1)

gen dict_1=(dictator_1/2500)*10
gen dict_2=(dictator_2/2500)*10

label var dict_1 "Donation to anybody"
label var dict_2 "Donation to MLP"
label var not_give_MLP_give_others "Give others, not MLP"


*** the election results and unemployment by region
gen elections=.
replace elections=47.06 if region==7 
replace elections=44.53 if region==13
replace elections=42.06 if region==6
replace elections=37.01 if region==11
replace elections=36.68 if region==4

gen elections1=.
replace elections1=31.04 if region==7 
replace elections1=28.16 if region==13
replace elections1=27.78 if region==6
replace elections1=22.98 if region==11
replace elections1=23.08 if region==4

gen reg_unempl=.
replace reg_unempl=12.2 if region==7
replace reg_unempl=11.7 if region==13
replace reg_unempl=9.9 if region==6
replace reg_unempl=11.7  if region==11
replace reg_unempl=9.6 if region==4

gen immigrant_2gen=(bplace_father==0|bplace_mother==0)
label var immigrant_2gen "Immigrant parents"

label var correct "Correct prior"
label var incorrect "Incorrect prior"

tab whomvoted_past, gen(voted_past)
gen not_voted_past=(voted_past5==1| voted_past6==1| voted_past8==1)

rename voted_past1 voted_2012_Hollande
rename voted_past2 voted_2012_Sarkozy
rename voted_past3 voted_2012_Melenchon
rename voted_past4 voted_2012_MLP
rename voted_past7 voted_2012_other
rename not_voted_past voted_2012_nv
drop voted_past8 voted_past6 voted_past5

label var voted_2012_MLP "Voted MLP, 2012"

gen not_voted_2012_MLP=1-voted_2012_MLP
label var not_voted_2012_MLP "Voted MLP, 2012"

gen treatment_het=treatment+1
replace treatment_het=treatment_het*100
replace treatment_het=treatment_het+1 if correct
replace treatment_het=treatment_het+10 if voted_2012_MLP

label define treatments_het 100 "Control$\times$Incorrect$\times$Not voted FN" 200 "Alt-Facts$\times$Incorrect$\times$Not voted FN" 300 "Facts$\times$Incorrect$\times$Not voted FN" 400 "Fact-Check$\times$Incorrect$\times$Not voted FN" 110 "Control$\times$Incorrect$\times$Voted FN" 210 "Alt-Facts$\times$Incorrect$\times$Voted FN" 310 "Facts$\times$Incorrect$\times$Voted FN" 410 "Fact-Check$\times$Incorrect$\times$Voted FN" 101 "Control$\times$Correct$\times$Not voted FN" 201 "Alt-Facts$\times$Correct$\times$Not voted FN" 301 "Facts$\times$Correct$\times$Not voted FN" 401 "Fact-Check$\times$Correct$\times$Not voted FN"  111 "Control$\times$Correct$\times$Voted FN" 211 "Alt-Facts$\times$Correct$\times$Voted FN" 311 "Facts$\times$Correct$\times$Voted FN" 411 "Fact-Check$\times$Correct$\times$Voted FN"
label values treatment_het treatments_het

gen treatment_order=treatment
replace treatment_order=2 if treatment==3
replace treatment_order=3 if treatment==2

gen underestimate=(opinion_unemp==1)
gen overestimate=(opinion_unemp>2)
gen correctlyestimate=(opinion_unemp==2)

gen correct_MLP=correctlyestimate*MLP
gen correct_Both=correctlyestimate*Both
gen correct_Info=correctlyestimate*Info

gen under_MLP=underestimate*MLP
gen under_Both=underestimate*Both
gen under_Info=underestimate*Info

gen quota_educ1=quota_educ
replace quota_educ1=0 if education<5
drop quota_educ
rename quota_educ1 quota_educ

foreach var in voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv {
sum `var'
scalar MN=r(mean)
gen dm_`var'=`var'-MN
}
}

**************************************************************************************************************************************************************************************
**** Analysis
**************************************************************************************************************************************************************************************

**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**** FIGURES IN THE MAIN TEXT
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************


graph set window fontface garamond /// to change font to times new roman

**************************************************************************************************************************************************************************************
**** FIGURE 1 
**************************************************************************************************************************************************************************************

**************************************************************************************************************************************************************************************
**** FIGURE 1  Panel A
**************************************************************************************************************************************************************************************
	
	sum  willvoteMLP if treatment_order == 0
	local control_mean = r(mean)
	
graph bar (mean) willvoteMLP, asyvars over(treatment_order, gap(20) label(nolabel)) ///
	graphregion(color(white)) ytitle("Will vote for MLP") title("All respondents", color(black)) ///
	bar( 1, fcolor(sand)) bar(2, fcolor(erose)) bar(3, fcolor(gs4)) bar(4, fcolor(ebblue)) ///
	legend(label(1 "Control") label(2 "Alt-Facts") label(3 "Fact-Check") label(4 "Facts")) ///
	yscale(r(.3 .5)) exclude0 yla(.3(.05).5) yline(`control_mean',  lpattern(dash) lcolor(cranberry))
	
graph save "$figures/figure_1_A", replace

**************************************************************************************************************************************************************************************
**** FIGURE 1  Panel B
**************************************************************************************************************************************************************************************
	
	sum  willvoteMLP if treatment_order == 0 & overestimate==1
	local control_mean = r(mean)
	
graph bar (mean) willvoteMLP if overestimate==1, asyvars over(treatment_order, gap(20) label(nolabel)) ///
	graphregion(color(white)) ytitle("Will vote for MLP") title("Respondents with overestimated prior", color(black)) ///
	bar( 1, fcolor(sand)) bar(2, fcolor(erose)) bar(3, fcolor(gs4)) bar(4, fcolor(ebblue)) ///
	legend(label(1 "Control") label(2 "Alt-Facts") label(3 "Fact-Check") label(4 "Facts")) ///
	yscale(r(.3 .5)) exclude0 yla(.3(.05).5) yline(`control_mean',  lpattern(dash) lcolor(cranberry))

graph save "$figures/figure_1_B", replace 

grc1leg   "$figures/figure_1_A" ///
		"$figures/figure_1_B",   ///
		scheme(s1mono) legendfrom("$figures/figure_1_B") ycommon
		
graph save "$figures/figure_1", replace
graph export "$figures/figure_1_A.eps", replace

erase  "$figures/figure_1_A.gph" 
erase "$figures/figure_1_B.gph"

**************************************************************************************************************************************************************************************
**** FIGURE 2 
**************************************************************************************************************************************************************************************

twoway (histogram test_refug_men if treatment==0, bin(10) color(sand))  (histogram test_refug_men if treatment==1, bin(10)  fcolor(none) lcolor(purple)), legend(order(1 "Control" 2 "Alt-Facts" )) xline(6, lpattern (solid))  xline(9.5, lpattern (dash))  xlab("") xtitle("") graphregion(color(white))
graph save  "$figures/refug_men_mlp.gph", replace

twoway (histogram test_refug_men if treatment==2, bin(10) color(ebblue))  (histogram test_refug_men if treatment==3, bin(10)  fcolor(none) lcolor(black)), legend(order(1 "Facts" 2 "Fact-Check" )) xline(6) xlab("") xtitle("") xline(9.5, lpattern (dash)) graphregion(color(white))
graph save  "$figures/refug_men_info", replace

twoway (histogram test_refug_men if treatment==0, bin(10) color(sand))  (histogram test_refug_men if treatment==2, bin(10)  fcolor(none) lcolor(ebblue)), legend(order(1 "Control" 2 "Facts" )) xline(6)  xlab("") xtitle("") xline(9.5, lpattern (dash)) graphregion(color(white))
graph save  "$figures/refug_men_mlp1", replace

twoway (histogram test_refug_men if treatment==1, bin(10) color(erose))  (histogram test_refug_men if treatment==3, bin(10)  fcolor(none) lcolor(black)), legend(order(1 "Alt-Facts" 2 "Fact-Check" )) xline(6) xlab("") xtitle("") xline(9.5, lpattern (dash)) graphregion(color(white))
graph save  "$figures/refug_men_info1", replace


graph combine "$figures/refug_men_mlp"  "$figures/refug_men_mlp1"  "$figures/refug_men_info" "$figures/refug_men_info1" , ycommon title("The share of men among refugees, 10 categories") note("Vertical lines: solid - Fact; dashed - Alt-Facts") graphregion(color(white))
graph save "$figures/figure_2", replace
graph export "$figures/figure_2.eps", replace

erase "$figures/refug_men_mlp.gph"  
erase "$figures/refug_men_mlp1.gph"  
erase "$figures/refug_men_info.gph"  
erase "$figures/refug_men_info1.gph"

**************************************************************************************************************************************************************************************
**** FIGURE 3 
**************************************************************************************************************************************************************************************


twoway (histogram test_labour_mig15 if treatment==0, bin(10) color(sand))  (histogram test_labour_mig15 if treatment==1, bin(10)  fcolor(none) lcolor(purple)), legend(order(1 "Control" 2 "Alt-Facts" )) xline(5)  xlab("") xtitle("") xline(1.5, lpattern (dash)) graphregion(color(white))
graph save "$figures/labour_mig_mlp", replace

twoway (histogram test_labour_mig15 if treatment==2, bin(10) color(ebblue))  (histogram test_labour_mig15 if treatment==3, bin(10)  fcolor(none) lcolor(black)), legend(order(1 "Facts" 2 "Fact-Check" )) xline(5)  xlab("") xtitle("") xline(1.5, lpattern (dash)) graphregion(color(white))
graph save "$figures/labour_mig_info", replace

twoway (histogram test_labour_mig15 if treatment==0, bin(10) color(sand))  (histogram test_labour_mig15 if treatment==2, bin(10)  fcolor(none) lcolor(ebblue)), legend(order(1 "Control" 2 "Facts" )) xline(5)  xlab("") xtitle("") xline(1.5, lpattern (dash)) graphregion(color(white))
graph save "$figures/labour_mig_mlp1", replace

twoway (histogram test_labour_mig15 if treatment==1, bin(10) color(erose))  (histogram test_labour_mig15 if treatment==3, bin(10)  fcolor(none) lcolor(black)), legend(order(1 "Alt-Facts" 2 "Fact-Check"  )) xline(5)  xlab("") xtitle("") xline(1.5, lpattern (dash)) graphregion(color(white))
graph save "$figures/labour_mig_info1", replace


graph combine "$figures/labour_mig_mlp" "$figures/labour_mig_mlp1" "$figures/labour_mig_info"   "$figures/labour_mig_info1"  , ycommon title("The share of working among immigrants, 10 categories") note("Vertical lines: solid - Fact; dashed - Alt-Facts") graphregion(color(white))
graph save "$figures/figure_3", replace
graph export "$figures/figure_3.eps", replace

erase "$figures/labour_mig_mlp.gph"  
erase "$figures/labour_mig_mlp1.gph"   
erase "$figures/labour_mig_info.gph"     
erase "$figures/labour_mig_info1.gph" 

**************************************************************************************************************************************************************************************
**** FIGURE 4 
**************************************************************************************************************************************************************************************


twoway (histogram  reason_mig if treatment==0, bin(3) color(sand))  (histogram  reason_mig if treatment==2, bin(3)  fcolor(none) lcolor(ebblue)), legend(order(1 "Control" 2 "Facts" ))   xlab("") xtitle("")         text(.3 1.35 "Economic",  color(gs2)) text(.5 2 "Security",  color(gs2))   text(.07 2.65 "Other",  color(gs2))  graphregion(color(white))
graph save "$figures/reason_mig_info", replace

twoway (histogram  reason_mig if treatment==1, bin(3) color(erose))  (histogram  reason_mig if treatment==3, bin(3)  fcolor(none) lcolor(black)), legend(order(1 "Alt-Facts" 2 "Fact-Check" ))   xlab("") xtitle("")  text(.3 1.35 "Economic",  color(gs2)) text(.5 2 "Security",  color(gs2))   text(.07 2.65 "Other",  color(gs2))  graphregion(color(white))
graph save "$figures/reason_mig_mlp", replace


twoway (histogram  reason_mig if treatment==0, bin(3) color(sand))  (histogram  reason_mig if treatment==1, bin(3)  fcolor(none) lcolor(purple)), legend(order(1 "Control" 2 "Alt-Facts" ))   xlab("") xtitle("")     text(.3 1.35 "Economic",  color(gs2)) text(.5 2 "Security",  color(gs2))   text(.07 2.65 "Other",  color(gs2)) graphregion(color(white))
graph save "$figures/reason_mig_info1", replace

twoway (histogram  reason_mig if treatment==2, bin(3) color(ebblue))  (histogram  reason_mig if treatment==3, bin(3)  fcolor(none) lcolor(black)), legend(order(1 "Facts" 2 "Fact-Check" ))   xlab("") xtitle("")     text(.3 1.35 "Economic",  color(gs2)) text(.5 2 "Security",  color(gs2))   text(.07 2.65 "Other",  color(gs2)) graphregion(color(white))
graph save "$figures/reason_mig_mlp1", replace


graph combine "$figures/reason_mig_info1" "$figures/reason_mig_info"    "$figures/reason_mig_mlp"  "$figures/reason_mig_mlp1"  , ycommon title("Main reason for refugees to come") graphregion(color(white))
graph save "$figures/figure_4", replace
graph export "$figures/figure_4.eps", replace

erase  "$figures/reason_mig_info1.gph"   
erase "$figures/reason_mig_info.gph"      
erase "$figures/reason_mig_mlp.gph"    
erase "$figures/reason_mig_mlp1.gph" 

**************************************************************************************************************************************************************************************
**** FIGURE 5 
**************************************************************************************************************************************************************************************

	sum  agree if treatment_order == 0 
	local control_mean = r(mean)
	
graph bar (mean) agree, asyvars over(treatment_order, gap(20) label(nolabel)) ///
	graphregion(color(white)) ytitle("agree with MLP on immigration policy") title("Agree or strongly agree with MLP on immigration, fraction", color(black)) ///
	bar( 1, fcolor(sand)) bar(2, fcolor(erose)) bar(3, fcolor(gs4)) bar(4, fcolor(ebblue)) ///
	legend(label(1 "Control") label(2 "Alt-Facts") label(3 "Fact-Check") label(4 "Facts")) ///
	yscale(r(.49 .6)) exclude0 yla(.5(.02).6) yline(`control_mean',  lpattern(dash) lcolor(cranberry))
	
graph save "$figures/figure_5", replace
graph export "$figures/figure_5.eps", replace


**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**** TABLES IN THE MAIN TEXT
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************


**************************************************************************************************************************************************************************************
**** TABLE 1 ****
**************************************************************************************************************************************************************************************



set more off
foreach var in children{
sum `var' if MLP
scalar mean_mlp=r(mean)
sum `var' if Both
scalar mean_both=r(mean)
sum `var' if Info
scalar mean_info=r(mean)
sum `var' if Control==1
scalar mean_control=r(mean)
reg `var'  MLP Both Info , r
test MLP
scalar mlp_control=r(p)
test Both
scalar both_control=r(p)
test Info
scalar info_control=r(p)
test MLP=Info
scalar mlp_info=r(p)
test MLP=Both
scalar mlp_both=r(p)
test Info=Both
scalar info_both=r(p)
outreg2 using $tables/table_1_transposed.xls, replace label addstat(mean_mlp, mean_mlp, mean_both,mean_both,mean_info, mean_info, mean_control,mean_control, mlp_control,mlp_control, both_control,both_control,info_control,info_control,mlp_both, mlp_both, info_both, info_both, mlp_info, mlp_info) 
}


*** balancing tests:
local balancing_var " num_children dmarried dsingle income dland_owner dstudent dunemployed dworker dretired dwage dbenefits dpension dtelevision dradio dinternet dcatholic dmuslim dnorelig voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv voted_FN opinion_unemp correct correctlyestimate overestimate underestimate"
 

foreach var in `balancing_var' {
sum `var' if MLP==1
scalar mean_mlp=r(mean)
sum `var' if Both==1
scalar mean_both=r(mean)
sum `var' if Info==1
scalar mean_info=r(mean)
sum `var' if Control==1
scalar mean_control=r(mean)
reg `var'  MLP Both Info , r
test MLP
scalar mlp_control=r(p)
test Both
scalar both_control=r(p)
test Info
scalar info_control=r(p)
test MLP=Info
scalar mlp_info=r(p)
test MLP=Both
scalar mlp_both=r(p)
test Info=Both
scalar info_both=r(p)
outreg2 using $tables/table_1_transposed.xls, append label addstat(mean_mlp, mean_mlp, mean_both,mean_both,mean_info, mean_info, mean_control,mean_control, mlp_control,mlp_control, both_control,both_control,info_control,info_control,mlp_both, mlp_both, info_both, info_both, mlp_info, mlp_info) 
}


**************************************************************************************************************************************************************************************
**** TABLE 2 ****
**************************************************************************************************************************************************************************************

 local regnom   "$tables/table_2"
 eststo clear

qui eststo: reg willvoteMLP                    i.treatment   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r

test 1.treatment=3.treatment
estadd scalar Pval_1eq3 = r(p)

test 2.treatment=3.treatment
estadd scalar Pval_2eq3 = r(p)

test 1.treatment=2.treatment
estadd scalar Pval_1eq2 = r(p)

test 1.treatment+2.treatment=3.treatment
estadd scalar Pvar_1plus2eq3 = r(p)

sum willvoteMLP if treatment==0
estadd scalar mean_DV_incontrol = r(mean)

qui eststo: reg distance_correct_refug_men     i.treatment  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r

test 1.treatment=3.treatment
estadd scalar Pval_1eq3 = r(p)

test 2.treatment=3.treatment
estadd scalar Pval_2eq3 = r(p)

test 1.treatment=2.treatment
estadd scalar Pval_1eq2 = r(p)

test 1.treatment+2.treatment=3.treatment
estadd scalar Pvar_1plus2eq3 = r(p)

sum distance_correct_refug_men if treatment==0
estadd scalar mean_DV_incontrol = r(mean)

qui eststo: reg distance_correct_labour_mig    i.treatment  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r

test 1.treatment=3.treatment
estadd scalar Pval_1eq3 = r(p)

test 2.treatment=3.treatment
estadd scalar Pval_2eq3 = r(p)

test 1.treatment=2.treatment
estadd scalar Pval_1eq2 = r(p)

test 1.treatment+2.treatment=3.treatment
estadd scalar Pvar_1plus2eq3 = r(p)

sum distance_correct_labour_mig if treatment==0
estadd scalar mean_DV_incontrol = r(mean)

qui eststo: reg dtest_refug_men                i.treatment  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r

test 1.treatment=3.treatment
estadd scalar Pval_1eq3 = r(p)

test 2.treatment=3.treatment
estadd scalar Pval_2eq3 = r(p)

test 1.treatment=2.treatment
estadd scalar Pval_1eq2 = r(p)

test 1.treatment+2.treatment=3.treatment
estadd scalar Pvar_1plus2eq3 = r(p)

sum dtest_refug_men if treatment==0
estadd scalar mean_DV_incontrol = r(mean)

qui eststo: reg dtest_labour_mig               i.treatment   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r

test 1.treatment=3.treatment
estadd scalar Pval_1eq3 = r(p)

test 2.treatment=3.treatment
estadd scalar Pval_2eq3 = r(p)

test 1.treatment=2.treatment
estadd scalar Pval_1eq2 = r(p)

test 1.treatment+2.treatment=3.treatment
estadd scalar Pvar_1plus2eq3 = r(p)

sum dtest_labour_mig if treatment==0
estadd scalar mean_DV_incontrol = r(mean)

qui eststo: reg reason_migration_economic      i.treatment i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r

test 1.treatment=3.treatment
estadd scalar Pval_1eq3 = r(p)

test 2.treatment=3.treatment
estadd scalar Pval_2eq3 = r(p)

test 1.treatment=2.treatment
estadd scalar Pval_1eq2 = r(p)

test 1.treatment+2.treatment=3.treatment
estadd scalar Pvar_1plus2eq3 = r(p)


sum reason_migration_economic if treatment==0
estadd scalar mean_DV_incontrol = r(mean)

qui eststo: reg agree                           i.treatment            i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r

test 1.treatment=3.treatment
estadd scalar Pval_1eq3 = r(p)

test 2.treatment=3.treatment
estadd scalar Pval_2eq3 = r(p)

test 1.treatment=2.treatment
estadd scalar Pval_1eq2 = r(p)

test 1.treatment+2.treatment=3.treatment
estadd scalar Pvar_1plus2eq3 = r(p)


sum agree if treatment==0
estadd scalar mean_DV_incontrol = r(mean)

esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace scalar(mean_DV_incontrol Pval_1eq3 Pval_2eq3 Pval_1eq2 Pvar_1plus2eq3)  keep(1.treatment 3.treatment 2.treatment ) order(1.treatment 3.treatment 2.treatment  )

esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label scalars(mean_DV_incontrol Pval_1eq3 Pval_2eq3 Pval_1eq2 Pvar_1plus2eq3)  keep(1.treatment 3.treatment 2.treatment  ) order(1.treatment 3.treatment 2.treatment  )
 
 
*************************************************************************************************
*** TABLE 3 ****
*************************************************************************************************



eststo clear 
local regnom   "$tables/table_3"

qui eststo:  reg willvoteMLP  MLP Both Info  correct_MLP correct_Both correct_Info      under_MLP under_Both  under_Info underestimate  correctlyestimate   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv , r 
qui eststo:  reg distance_correct_refug_men  MLP Both Info  correct_MLP correct_Both correct_Info      under_MLP under_Both  under_Info underestimate  correctlyestimate   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv , r 
qui eststo:  reg distance_correct_labour_mig  MLP Both Info  correct_MLP correct_Both correct_Info      under_MLP under_Both  under_Info underestimate  correctlyestimate   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv , r 
qui eststo:  reg dtest_refug_men  MLP Both Info  correct_MLP correct_Both correct_Info      under_MLP under_Both  under_Info underestimate  correctlyestimate   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv , r 
qui eststo:  reg dtest_labour_mig  MLP Both Info  correct_MLP correct_Both correct_Info      under_MLP under_Both  under_Info underestimate  correctlyestimate   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv , r 

esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(MLP Both Info  correct_MLP correct_Both correct_Info      under_MLP under_Both  under_Info  ) 
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(MLP Both Info  correct_MLP correct_Both correct_Info      under_MLP under_Both  under_Info)
eststo clear 


**************************************************************************************************************************************************************************************
**** TABLE 4 ****
**************************************************************************************************************************************************************************************

 
eststo clear 
local regnom   "$tables/table_4"

qui eststo: reg willvoteMLP     test_refug_men     test_labour_mig15            														  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if Control,r 
qui eststo: reg willvoteMLP                     									 test_refug_men  test_labour_mig15					i.treatment  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv,r 
qui eststo: reg reason_migration_economic     test_refug_men     test_labour_mig15            											  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if Control,r 
qui eststo: reg reason_migration_economic                     						 test_refug_men  test_labour_mig15					i.treatment  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv,r 
qui eststo: reg agree   test_refug_men     test_labour_mig15            														 			  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if Control,r 
qui eststo: reg agree                     											 test_refug_men  test_labour_mig15					i.treatment  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv,r 
		
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(1.treatment 3.treatment 2.treatment    test_refug_men  test_labour_mig15 ) order( test_refug_men  test_labour_mig15 reason_migration_economic agree 1.treatment 3.treatment 2.treatment   )
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(1.treatment 3.treatment 2.treatment   test_refug_men  test_labour_mig15   ) order( test_refug_men  test_labour_mig15 reason_migration_economic agree 1.treatment 3.treatment 2.treatment )
eststo clear 


**************************************************************************************************************************************************************************************
**** TABLE 5 --  Panel A ****
**************************************************************************************************************************************************************************************

eststo clear 

local regnom   "$tables/table_5_A"
qui eststo: reg willvoteMLP	dict_2      				i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv , r 
qui eststo: reg willvoteMLP	dict_2 dict_1       		i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv , r 
qui eststo: reg willvoteMLP	not_give_MLP_give_others  	i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv , r 
qui eststo: reg dict_2	i.treatment dict_1  			i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg not_give_MLP_give_others	 i.treatment  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv , r 

esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(1.treatment 3.treatment 2.treatment dict_2	dict_1 not_give_MLP_give_others) order(dict_2	dict_1 not_give_MLP_give_others 1.treatment 3.treatment 2.treatment )
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(1.treatment 3.treatment 2.treatment dict_2	dict_1 not_give_MLP_give_others) order(dict_2	dict_1 not_give_MLP_give_others 1.treatment 3.treatment 2.treatment )
eststo clear 
label values treatment treatments

**************************************************************************************************************************************************************************************
**** TABLE 5 -- Panel B ****
**************************************************************************************************************************************************************************************


**************************************************************************************************************************************************************************************
**** list experiment table

label var list_with_MLP "List with MLP"
eststo clear 

local regnom  "$tables/table_5_B"

qui eststo: reg list_number  list_with_MLP, r
qui eststo: reg list_number  list_with_MLP if willvoteMLP, r
qui eststo: reg list_number  list_with_MLP if ! willvoteMLP, r
qui eststo: reg list_number  willvoteMLP c.(willvoteMLP)#c.(list_with_MLP), r
qui eststo: reg list_number  c.(list_with_MLP)#c.(Control) c.(list_with_MLP)#c.(MLP) c.(list_with_MLP)#c.(Info) c.(list_with_MLP)#c.(Both), r
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(list_with_MLP willvoteMLP c.willvoteMLP#c.list_with_MLP  c.list_with_MLP#c.Control c.list_with_MLP#c.MLP c.list_with_MLP#c.Both c.list_with_MLP#c.Info ) order(list_with_MLP willvoteMLP c.willvoteMLP#c.list_with_MLP  c.list_with_MLP#c.Control c.list_with_MLP#c.MLP c.list_with_MLP#c.Both c.list_with_MLP#c.Info )
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(list_with_MLP willvoteMLP c.willvoteMLP#c.list_with_MLP c.list_with_MLP#c.Control c.list_with_MLP#c.MLP  c.list_with_MLP#c.Both c.list_with_MLP#c.Info)
eststo clear 


**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
****** Appendix tables
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************


**************************************************************************************************************************************************************************************
**** TABLE A1 ****
**************************************************************************************************************************************************************************************

log using $tables/table_A1, replace
sum willvoteMLP reason_migration_economic agree distance_correct_refug_men distance_correct_labour_mig distance_french dtest_refug_men dtest_labour_mig dtest_french MLP Both Info Control
log close

**************************************************************************************************************************************************************************************
**** TABLE A2 ****
**************************************************************************************************************************************************************************************

** Generate interactions of treatments with all voiting controls (PVinteractions): 

** TREATMENTS:
** MLP=(treatment==1)
** Info=(treatment==2)
** Both=(treatment==3)
** Control=(treatment==0)

** VOTING CONTROLS: 
** voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_other voted_2012_nv

** INTERACTIONS OF TREATMENTS AND VOTING CONTROLS: 
** c.dm_voted_2012_MLP#c.MLP c.dm_voted_2012_MLP#c.Info c.dm_voted_2012_MLP#c.Both
** c.dm_voted_2012_Hollande#c.MLP c.dm_voted_2012_Hollande#c.Info c.dm_voted_2012_Hollande#c.Both
** c.dm_voted_2012_Sarkozy#c.MLP c.dm_voted_2012_Sarkozy#c.Info c.dm_voted_2012_Sarkozy#c.Both
** c.dm_voted_2012_Melenchon#c.MLP c.dm_voted_2012_Melenchon#c.Info c.dm_voted_2012_Melenchon#c.Both
** c.dm_voted_2012_other#c.MLP c.dm_voted_2012_other#c.Info c.dm_voted_2012_other#c.Both
** c.dm_voted_2012_nv#c.MLP c.dm_voted_2012_nv#c.Info c.dm_voted_2012_nv#c.Both

global PVinteractions  c.dm_voted_2012_MLP#c.MLP c.dm_voted_2012_MLP#c.Info c.dm_voted_2012_MLP#c.Both c.dm_voted_2012_Hollande#c.MLP c.dm_voted_2012_Hollande#c.Info c.dm_voted_2012_Hollande#c.Both c.dm_voted_2012_Sarkozy#c.MLP c.dm_voted_2012_Sarkozy#c.Info c.dm_voted_2012_Sarkozy#c.Both c.dm_voted_2012_Melenchon#c.MLP c.dm_voted_2012_Melenchon#c.Info c.dm_voted_2012_Melenchon#c.Both c.dm_voted_2012_other#c.MLP c.dm_voted_2012_other#c.Info c.dm_voted_2012_other#c.Both c.dm_voted_2012_nv#c.MLP c.dm_voted_2012_nv#c.Info c.dm_voted_2012_nv#c.Both
 
local regnom  "$tables/table_A2"
eststo clear

foreach var in  willvoteMLP  reason_migration_economic agree {

qui eststo: reg `var' i.treatment   i.sexe i.quota_age i.quota_edu i.region_residence, r
qui eststo: reg `var' i.treatment   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  , r
qui eststo: reg `var' i.treatment   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r
qui eststo: reg `var' i.treatment  $PVinteractions i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r
}
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace scalar(mean_DV_incontrol Pval_1eq3 Pval_2eq3 Pval_1eq2 Pvar_1plus2eq3)  keep(1.treatment 3.treatment 2.treatment ) order(1.treatment 3.treatment 2.treatment  )
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f)  label  keep(1.treatment 3.treatment 2.treatment  ) order(1.treatment 3.treatment 2.treatment  )


**************************************************************************************************************************************************************************************
**** TABLE A3 Panel A ****
**************************************************************************************************************************************************************************************


local regnom  "$tables/table_A3_A"
eststo clear

foreach var in  distance_correct_refug_men  dtest_refug_men{

qui eststo: reg `var' i.treatment   i.sexe i.quota_age i.quota_edu i.region_residence, r
qui eststo: reg `var' i.treatment   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  , r
qui eststo: reg `var' i.treatment   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r
qui eststo: reg `var' i.treatment   $PVinteractions i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r
}
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace scalar(mean_DV_incontrol Pval_1eq3 Pval_2eq3 Pval_1eq2 Pvar_1plus2eq3)  keep(1.treatment 3.treatment 2.treatment ) order(1.treatment 3.treatment 2.treatment  )
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f)  label   keep(1.treatment 3.treatment 2.treatment  ) order(1.treatment 3.treatment 2.treatment  )


**************************************************************************************************************************************************************************************
**** TABLE A3 Panel B ****
**************************************************************************************************************************************************************************************

local regnom   "$tables/table_A3_B"
eststo clear

foreach var in  distance_correct_labour_mig  dtest_labour_mig{

qui eststo: reg `var' i.treatment   i.sexe i.quota_age i.quota_edu i.region_residence, r
qui eststo: reg `var' i.treatment   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  , r
qui eststo: reg `var' i.treatment   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r
qui eststo: reg `var' $PVinteractions i.treatment   i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r
}
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace scalar(mean_DV_incontrol Pval_1eq3 Pval_2eq3 Pval_1eq2 Pvar_1plus2eq3)  keep(1.treatment 3.treatment 2.treatment ) order(1.treatment 3.treatment 2.treatment  )
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f)  label   keep(1.treatment 3.treatment 2.treatment  ) order(1.treatment 3.treatment 2.treatment  )


**************************************************************************************************************************************************************************************
**** TABLE A4 ****
**************************************************************************************************************************************************************************************

local regnom   "$tables/table_A4"
eststo clear 
 
qui eststo: reg distance_french_2ww            i.treatment i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
sum distance_french_2ww if treatment==0
estadd scalar mean_DV_incontrol = r(mean)

qui eststo: reg dtest_french_2ww               i.treatment i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
sum dtest_french_2ww if treatment==0
estadd scalar mean_DV_incontrol = r(mean)

esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  scalar(mean_DV_incontrol) label replace keep(1.treatment 3.treatment 2.treatment ) order(1.treatment 3.treatment 2.treatment )
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(1.treatment 3.treatment 2.treatment  )
eststo clear 

**************************************************************************************************************************************************************************************
**** TABLE A5 Panel A ****
**************************************************************************************************************************************************************************************


set more off
local path $tables 

local regnom   "$tables/table_A5_A"
 eststo clear

qui eststo: reg test_refug_men overestimate underestimate  if Control==1, r

qui eststo: reg test_refug_men overestimate underestimate i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if Control==1, r

qui eststo: reg test_labour_mig15 overestimate underestimate  if Control==1, r

qui eststo: reg test_labour_mig15 overestimate underestimate i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if Control==1, r

esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(overestimate underestimate) 
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(overestimate underestimate)
eststo clear 

**************************************************************************************************************************************************************************************
**** TABLE A5 Panel B ****
**************************************************************************************************************************************************************************************


local regnom   "$tables/table_A5_B"
 eststo clear

qui eststo: reg test_refug_men opinion_unemp  underestimate if Control==1, r

qui eststo: reg test_refug_men opinion_unemp  underestimate i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if Control==1, r

qui eststo: reg test_labour_mig15 opinion_unemp underestimate  if Control==1, r

qui eststo: reg test_labour_mig15 opinion_unemp underestimate  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if Control==1, r

esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(opinion_unemp underestimate) 
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(opinion_unemp underestimate)
eststo clear 


**************************************************************************************************************************************************************************************
**** HETEROGENEITY
**************************************************************************************************************************************************************************************

**************************************************************************************************************************************************************************************
**** TABLE A6 Panel A ****
**************************************************************************************************************************************************************************************


 local regnom   "$tables/table_A6_A"
qui eststo: reg willvoteMLP    						i.treatment  c.(voted_2012_MLP)#c.(MLP) c.(voted_2012_MLP)#c.(Info) c.(voted_2012_MLP)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_refug_men    		i.treatment  c.(voted_2012_MLP)#c.(MLP) c.(voted_2012_MLP)#c.(Info) c.(voted_2012_MLP)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_labour_mig   		i.treatment  c.(voted_2012_MLP)#c.(MLP) c.(voted_2012_MLP)#c.(Info) c.(voted_2012_MLP)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg reason_migration_economic           i.treatment  c.(voted_2012_MLP)#c.(MLP) c.(voted_2012_MLP)#c.(Info) c.(voted_2012_MLP)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg agree           						i.treatment  c.(voted_2012_MLP)#c.(MLP) c.(voted_2012_MLP)#c.(Info) c.(voted_2012_MLP)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(c.voted_2012_MLP#c.MLP      c.voted_2012_MLP#c.Both  c.voted_2012_MLP#c.Info) order(c.voted_2012_MLP#c.MLP      c.voted_2012_MLP#c.Both  c.voted_2012_MLP#c.Info)
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(c.voted_2012_MLP#c.MLP     c.voted_2012_MLP#c.Both  c.voted_2012_MLP#c.Info )
eststo clear 


**************************************************************************************************************************************************************************************
**** TABLE A6 Panel B ****
**************************************************************************************************************************************************************************************

cap drop media_TV
gen media_TV=(source_media==1)
label var media_TV "News from TV"

****** NOTE THIS IS ON THE SUBSAMPLE OF THOSE WHO DO CONSUME NEWS

local regnom    "$tables/table_A6_B"
qui eststo: reg willvoteMLP  						media_TV  i.treatment  c.(media_TV)#c.(MLP) c.( media_TV)#c.(Info) c.(media_TV)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if source_media!=8, r 
qui eststo: reg distance_correct_refug_men 			media_TV  i.treatment  c.(media_TV)#c.(MLP) c.( media_TV)#c.(Info) c.(media_TV)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if source_media!=8, r 
qui eststo: reg distance_correct_labour_mig 		media_TV  i.treatment  c.(media_TV)#c.(MLP) c.(media_TV)#c.(Info) c.(media_TV)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if source_media!=8, r 
qui eststo: reg reason_migration_economic 			media_TV  i.treatment  c.(media_TV)#c.(MLP) c.( media_TV)#c.(Info) c.(media_TV)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if source_media!=8, r 
qui eststo: reg agree 								media_TV  i.treatment  c.(media_TV)#c.(MLP) c.(media_TV)#c.(Info) c.(media_TV)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if source_media!=8, r 
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(c.media_TV#c.MLP     c.media_TV#c.Both c.media_TV#c.Info  media_TV) order(c.media_TV#c.MLP     c.media_TV#c.Both c.media_TV#c.Info  media_TV)
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(c.media_TV#c.MLP     c.media_TV#c.Both  c.media_TV#c.Info media_TV)
eststo clear

**************************************************************************************************************************************************************************************
**** TABLE A6 Panel C ****
**************************************************************************************************************************************************************************************

cap drop media_internet
gen media_internet=(source_media==3)
label var media_internet "News from internet"

****** NOTE THIS IS ON THE SUBSAMPLE OF THOSE WHO DO CONSUME NEWS

local regnom  "$tables/table_A6_C"
qui eststo: reg willvoteMLP  						media_internet  i.treatment  c.(media_internet)#c.(MLP) c.( media_internet)#c.(Info) c.(media_internet)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if source_media!=8, r 
qui eststo: reg distance_correct_refug_men 			media_internet  i.treatment  c.(media_internet)#c.(MLP) c.( media_internet)#c.(Info) c.(media_internet)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if source_media!=8, r 
qui eststo: reg distance_correct_labour_mig 		media_internet  i.treatment  c.(media_internet)#c.(MLP) c.(media_internet)#c.(Info) c.(media_internet)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if source_media!=8, r 
qui eststo: reg reason_migration_economic 			media_internet  i.treatment  c.(media_internet)#c.(MLP) c.( media_internet)#c.(Info) c.(media_internet)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if source_media!=8, r 
qui eststo: reg agree 								media_internet  i.treatment  c.(media_internet)#c.(MLP) c.(media_internet)#c.(Info) c.(media_internet)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv if source_media!=8, r 
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(c.media_internet#c.MLP     c.media_internet#c.Both c.media_internet#c.Info  media_internet) order(c.media_internet#c.MLP     c.media_internet#c.Both c.media_internet#c.Info  media_internet)
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(c.media_internet#c.MLP     c.media_internet#c.Both  c.media_internet#c.Info media_internet)
eststo clear

**************************************************************************************************************************************************************************************
**** TABLE A6 Panel D ****
**************************************************************************************************************************************************************************************


gen on_soc_sec=1 if source_inc>1&source_inc<5
replace  on_soc_sec=0 if on_soc_sec==.
label var on_soc_sec "Income from soc.security"

local regnom   "$tables/table_A6_D"
qui eststo: reg willvoteMLP  						on_soc_sec  i.treatment  c.(on_soc_sec)#c.(MLP) c.(on_soc_sec)#c.(Info) c.(on_soc_sec)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_refug_men 			on_soc_sec  i.treatment  c.(on_soc_sec)#c.(MLP) c.(on_soc_sec)#c.(Info) c.(on_soc_sec)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_labour_mig 		on_soc_sec  i.treatment  c.(on_soc_sec)#c.(MLP) c.(on_soc_sec)#c.(Info) c.(on_soc_sec)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg reason_migration_economic 			on_soc_sec  i.treatment  c.(on_soc_sec)#c.(MLP) c.(on_soc_sec)#c.(Info) c.(on_soc_sec)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg agree 								on_soc_sec  i.treatment  c.(on_soc_sec)#c.(MLP) c.(on_soc_sec)#c.(Info) c.(on_soc_sec)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(c.on_soc_sec#c.MLP     c.on_soc_sec#c.Both  c.on_soc_sec#c.Info on_soc_sec) order(c.on_soc_sec#c.MLP     c.on_soc_sec#c.Both  c.on_soc_sec#c.Info on_soc_sec)
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(c.on_soc_sec#c.MLP      c.on_soc_sec#c.Both  c.on_soc_sec#c.Info on_soc_sec)
eststo clear



**************************************************************************************************************************************************************************************
**** TABLE A6 Panel E ****
**************************************************************************************************************************************************************************************

label var high_educ "Secondary education" 

local regnom   "$tables/table_A6_E"
qui eststo: reg willvoteMLP  				i.high_educ  i.treatment  c.(high_educ)#c.(MLP) c.( high_educ)#c.(Info) c.(high_educ)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_refug_men  i.high_educ  i.treatment  c.(high_educ)#c.(MLP) c.( high_educ)#c.(Info) c.(high_educ)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_labour_mig i.high_educ  i.treatment  c.(high_educ)#c.(MLP) c.( high_educ)#c.(Info) c.(high_educ)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg reason_migration_economic   i.high_educ  i.treatment  c.(high_educ)#c.(MLP) c.( high_educ)#c.(Info) c.(high_educ)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg agree					    i.high_educ  i.treatment  c.(high_educ)#c.(MLP) c.( high_educ)#c.(Info) c.(high_educ)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(c.high_educ#c.MLP     c.high_educ#c.Both  c.high_educ#c.Info ) order(c.high_educ#c.MLP     c.high_educ#c.Both  c.high_educ#c.Info )
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(c.high_educ#c.MLP      c.high_educ#c.Both  c.high_educ#c.Info)
eststo clear 


**************************************************************************************************************************************************************************************
**** TABLE A7 Panel A ****
**************************************************************************************************************************************************************************************

label var income "Income"

local regnom   "$tables/table_A7_A"
qui eststo: reg willvoteMLP    						i.treatment  c.(income)#c.(MLP) c.(income)#c.(Info) c.(income)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_refug_men    		i.treatment  c.(income)#c.(MLP) c.(income)#c.(Info) c.(income)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_labour_mig   		i.treatment  c.(income)#c.(MLP) c.(income)#c.(Info) c.(income)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg reason_migration_economic           i.treatment  c.(income)#c.(MLP) c.(income)#c.(Info) c.(income)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg agree           						i.treatment  c.(income)#c.(MLP) c.(income)#c.(Info) c.(income)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(c.income#c.MLP     c.income#c.Both c.income#c.Info  ) order(c.income#c.MLP     c.income#c.Both c.income#c.Info  )
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(c.income#c.MLP    c.income#c.Both  c.income#c.Info  )
eststo clear 

**************************************************************************************************************************************************************************************
**** TABLE A7 Panel B ****
**************************************************************************************************************************************************************************************

label var age "Age"

local regnom   "$tables/table_A7_B"
qui eststo: reg willvoteMLP    					age	i.treatment  c.(age)#c.(MLP) c.(age)#c.(Info) c.(age)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_refug_men    	age	i.treatment  c.(age)#c.(MLP) c.(age)#c.(Info) c.(age)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_labour_mig   	age	i.treatment  c.(age)#c.(MLP) c.(age)#c.(Info) c.(age)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg reason_migration_economic       age i.treatment  c.(age)#c.(MLP) c.(age)#c.(Info) c.(age)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg agree           					age	i.treatment  c.(age)#c.(MLP) c.(age)#c.(Info) c.(age)#c.Both  i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(c.age#c.MLP      c.age#c.Both  c.age#c.Info) order(c.age#c.MLP      c.age#c.Both  c.age#c.Info)
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(c.age#c.MLP     c.age#c.Both  c.age#c.Info )
eststo clear 

**************************************************************************************************************************************************************************************
**** TABLE A7 Panel C ****
**************************************************************************************************************************************************************************************

label var sexe "Male"

local regnom   "$tables/table_A7_C"
qui eststo: reg willvoteMLP    						i.treatment  c.(sexe)#c.(MLP) c.(sexe)#c.(Info) c.(sexe)#c.Both  i.income i.sexe sexe i.education  i.quota_age age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_refug_men    		i.treatment  c.(sexe)#c.(MLP) c.(sexe)#c.(Info) c.(sexe)#c.Both  i.income i.sexe sexe i.education  i.quota_age age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_labour_mig   		i.treatment  c.(sexe)#c.(MLP) c.(sexe)#c.(Info) c.(sexe)#c.Both  i.income i.sexe sexe i.education  i.quota_age age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg reason_migration_economic           i.treatment  c.(sexe)#c.(MLP) c.(sexe)#c.(Info) c.(sexe)#c.Both  i.income i.sexe sexe i.education  i.quota_age age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg agree           						i.treatment  c.(sexe)#c.(MLP) c.(sexe)#c.(Info) c.(sexe)#c.Both  i.income i.sexe sexe i.education  i.quota_age age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(c.sexe#c.MLP      c.sexe#c.Both c.sexe#c.Info ) order(c.sexe#c.MLP      c.sexe#c.Both c.sexe#c.Info )
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(c.sexe#c.MLP      c.sexe#c.Both c.sexe#c.Info )
eststo clear 

**************************************************************************************************************************************************************************************
**** TABLE A7 Panel D ****
**************************************************************************************************************************************************************************************


local regnom   "$tables/table_A7_D"

qui eststo: reg willvoteMLP    						i.treatment  c.(immigrant_2gen)#c.(MLP) c.(immigrant_2gen)#c.(Info) c.(immigrant_2gen)#c.Both  i.income i.sexe immigrant_2gen i.education  age i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_refug_men    		i.treatment  c.(immigrant_2gen)#c.(MLP) c.(immigrant_2gen)#c.(Info) c.(immigrant_2gen)#c.Both  i.income i.sexe immigrant_2gen i.education  age i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_labour_mig   		i.treatment  c.(immigrant_2gen)#c.(MLP) c.(immigrant_2gen)#c.(Info) c.(immigrant_2gen)#c.Both  i.income i.sexe immigrant_2gen i.education  age i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg reason_migration_economic           i.treatment  c.(immigrant_2gen)#c.(MLP) c.(immigrant_2gen)#c.(Info) c.(immigrant_2gen)#c.Both  i.income i.sexe immigrant_2gen i.education  age i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg agree           						i.treatment  c.(immigrant_2gen)#c.(MLP) c.(immigrant_2gen)#c.(Info) c.(immigrant_2gen)#c.Both  i.income i.sexe immigrant_2gen i.education  age i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(c.immigrant_2gen#c.MLP     c.immigrant_2gen#c.Both  c.immigrant_2gen#c.Info ) order(c.immigrant_2gen#c.MLP     c.immigrant_2gen#c.Both  c.immigrant_2gen#c.Info )
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(c.immigrant_2gen#c.MLP      c.immigrant_2gen#c.Both  c.immigrant_2gen#c.Info)
eststo clear 

**************************************************************************************************************************************************************************************
**** TABLE A7 Panel E ****
**************************************************************************************************************************************************************************************


label var left_right_axis "Score on left-right axis"

local regnom    "$tables/table_A7_E"
qui eststo: reg willvoteMLP  						left_right_axis  i.treatment  c.(left_right_axis)#c.(MLP) c.(left_right_axis)#c.(Info) c.(left_right_axis)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_refug_men 			left_right_axis  i.treatment  c.(left_right_axis)#c.(MLP) c.(left_right_axis)#c.(Info) c.(left_right_axis)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_labour_mig 		left_right_axis  i.treatment  c.(left_right_axis)#c.(MLP) c.(left_right_axis)#c.(Info) c.(left_right_axis)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg reason_migration_economic 			left_right_axis  i.treatment  c.(left_right_axis)#c.(MLP) c.(left_right_axis)#c.(Info) c.(left_right_axis)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg agree 								left_right_axis  i.treatment  c.(left_right_axis)#c.(MLP) c.(left_right_axis)#c.(Info) c.(left_right_axis)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(c.left_right_axis#c.MLP     c.left_right_axis#c.Both  c.left_right_axis#c.Info left_right_axis) order(c.left_right_axis#c.MLP     c.left_right_axis#c.Both  c.left_right_axis#c.Info left_right_axis)
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(c.left_right_axis#c.MLP      c.left_right_axis#c.Both  c.left_right_axis#c.Info left_right_axis)
eststo clear

**************************************************************************************************************************************************************************************
**** TABLE A7 Panel F ****
**************************************************************************************************************************************************************************************

**************************************************************************************************************************************************************************************

label var elections "Reg. vote for MLP, 2nd round"

local regnom   "$tables/table_A7_F"
qui eststo: reg willvoteMLP  						elections  i.treatment  c.(elections)#c.(MLP) c.(elections)#c.(Info) c.(elections)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_refug_men 			elections  i.treatment  c.(elections)#c.(MLP) c.(elections)#c.(Info) c.(elections)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg distance_correct_labour_mig 		elections  i.treatment  c.(elections)#c.(MLP) c.(elections)#c.(Info) c.(elections)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg reason_migration_economic 			elections  i.treatment  c.(elections)#c.(MLP) c.(elections)#c.(Info) c.(elections)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
qui eststo: reg agree 								elections  i.treatment  c.(elections)#c.(MLP) c.(elections)#c.(Info) c.(elections)#c.Both i.income i.sexe age i.education  i.quota_age i.region_residence i.religion dwage dmarried  voted_2012_Hollande voted_2012_Sarkozy voted_2012_Melenchon voted_2012_MLP voted_2012_other voted_2012_nv, r 
esttab using  `regnom',  b(%4.3f) se(%4.3f) ar2 starlevels({$^{*}$} 0.1 {$^{**}$} 0.05 {$^{***}$} 0.01)  tex  label replace keep(c.elections#c.MLP     c.elections#c.Both  c.elections#c.Info elections) order(c.elections#c.MLP     c.elections#c.Both  c.elections#c.Info elections)
esttab,  compress ar2 starlevels(* 0.1 ** 0.05 *** 0.01)  b(%4.3f) se(%4.3f) label   keep(c.elections#c.MLP      c.elections#c.Both  c.elections#c.Info elections)
eststo clear



**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**** FIGURES IN THE APPENDIX
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************
**************************************************************************************************************************************************************************************


**************************************************************************************************************************************************************************************
**** FIGURES A1 and A2 are generated by arcGis! 
**************************************************************************************************************************************************************************************

**************************************************************************************************************************************************************************************
**** FIGURE A3 
**************************************************************************************************************************************************************************************

twoway (histogram opinion_unemp if high_educ==1 , bin(10) color(olive_teal))  (histogram opinion_unemp if high_educ==0, bin(10)  fcolor(none) lcolor(dkgreen)), legend(order(1 "Secondary" 2 "Below second." )) xline(2.65)  xlab("") title("Education") xtitle("") graphregion(color(white))
graph save "$figures/opinion_unemp1", replace

twoway (histogram opinion_unemp if voted_2012_MLP==0, bin(10) color(olive_teal))  (histogram opinion_unemp if voted_2012_MLP==1, bin(10)  fcolor(none) lcolor(dkgreen)), legend(order(1 "Not voted MLP" 2 "Voted MLP" )) xline(2.65) xlab("") title("Vote for MLP in 2012") xtitle("") graphregion(color(white))
graph save "$figures/opinion_unemp2", replace

twoway (histogram opinion_unemp if reg_unempl<10, bin(10) color(olive_teal))  (histogram opinion_unemp if reg_unempl>10, bin(10)  fcolor(none) lcolor(dkgreen)), legend(order(1 "Lower" 2 "Higher" )) xline(2.65) xlab("") title("Regional unemloyment") xtitle("") graphregion(color(white))
graph save "$figures/opinion_unemp_reg_unemp", replace

twoway (histogram opinion_unemp if rural==1, bin(10) color(olive_teal))  (histogram opinion_unemp if rural==0, bin(10)  fcolor(none) lcolor(dkgreen)), legend(order(1 "Rural" 2 "Urban" )) xline(2.65) xlab("") title("Rural/Urban") xtitle("") graphregion(color(white))
graph save "$figures/opinion_unemp_rural", replace


graph combine "$figures/opinion_unemp1"  "$figures/opinion_unemp2" "$figures/opinion_unemp_reg_unemp" "$figures/opinion_unemp_rural", ycommon title("Prior on unemployment rate among immigrants, 10 categories") note("Full sample; vertical lines indicate 18\%") graphregion(color(white))
graph save "$figures/figure_A3", replace
graph export "$figures/figure_A3.pdf", replace

erase "$figures/opinion_unemp1.gph"  
erase "$figures/opinion_unemp2.gph" 
erase "$figures/opinion_unemp_reg_unemp.gph" 
erase "$figures/opinion_unemp_rural.gph"

**************************************************************************************************************************************************************************************
**** FIGURE A4 LEFT 
**************************************************************************************************************************************************************************************
	
	sum  willvoteMLP if treatment_order == 0 & voted_2012_MLP==0
	local control_mean = r(mean)
	
graph bar (mean) willvoteMLP if voted_2012_MLP==0, asyvars over(treatment_order, gap(20) label(nolabel)) ///
	graphregion(color(white)) ytitle("Intention to vote for MLP") ///
	title("Likely and very likely to vote for MLP, fraction", color(black)) ///
	subtitle("Sub-sample: Those, who did not vote for MLP in 2012 (1,945 obs.)") ///
	bar( 1, fcolor(sand)) bar(2, fcolor(erose)) bar(3, fcolor(gs4)) bar(4, fcolor(ebblue)) ///
	legend(label(1 "Control") label(2 "Alt-Facts") label(3 "Fact-Check") label(4 "Facts")) ///
	yscale(r(.2 .3)) exclude0 yla(.2(.02).3) yline(`control_mean',  lpattern(dash) lcolor(cranberry))
	
graph save "$figures/figure_A4_left", replace
graph export "$figures/figure_A4_left.pdf", replace

**************************************************************************************************************************************************************************************
**** FIGURE A4 RIGHT
**************************************************************************************************************************************************************************************

sum  willvoteMLP if treatment_order == 0 & voted_2012_MLP==1
	local control_mean = r(mean)
	
graph bar (mean) willvoteMLP if voted_2012_MLP==1, asyvars over(treatment_order, gap(20) label(nolabel)) ///
	graphregion(color(white)) ytitle("Intention to vote for MLP") ///
	title("Likely and very likely to vote for MLP, fraction", color(black)) ///
	subtitle("Sub-sample: Those, who voted for MLP in 2012 (535 obs.)") ///
	bar( 1, fcolor(sand)) bar(2, fcolor(erose)) bar(3, fcolor(gs4)) bar(4, fcolor(ebblue)) ///
	legend(label(1 "Control") label(2 "Alt-Facts") label(3 "Fact-Check") label(4 "Facts")) ///
	yscale(r(.7 .9)) exclude0 yla(.7(.05).9) yline(`control_mean',  lpattern(dash) lcolor(cranberry))

graph save "$figures/figure_A4_right", replace
graph export "$figures/figure_A4_right.pdf", replace


**************************************************************************************************************************************************************************************
**** FIGURE A5 
**************************************************************************************************************************************************************************************

*** French refugees in WWII

twoway (histogram test_french_2ww if treatment==0, bin(10) color(sand))  (histogram test_french_2ww if treatment==1, bin(10)  fcolor(none) lcolor(purple)), legend(order(1 "Control" 2 "Alt-Facts" )) xline(3.2) xlab("") xtitle("") graphregion(color(white))
graph save "$figures/french_2ww_mlp", replace

twoway (histogram test_french_2ww if treatment==2, bin(10) color(ebblue))  (histogram test_french_2ww if treatment==3, bin(10)  fcolor(none) lcolor(black)), legend(order(1 "Facts" 2 "Fact-Check" )) xline(3.2) xlab("") xtitle("") graphregion(color(white))
graph save "$figures/french_2ww_info", replace


twoway (histogram test_french_2ww if treatment==0, bin(10) color(sand))  (histogram test_french_2ww if treatment==2, bin(10)  fcolor(none) lcolor(ebblue)), legend(order(1 "Control" 2 "Facts")) xline(3.2) xlab("") xtitle("") graphregion(color(white))
graph save "$figures/french_2ww_mlp1", replace

twoway (histogram test_french_2ww if treatment==1, bin(10) color(erose))  (histogram test_french_2ww if treatment==3, bin(10)  fcolor(none) lcolor(black)), legend(order(1 "Alt-Facts" 2 "Fact-Check"  )) xline(3.2) xlab("") xtitle("") graphregion(color(white))
graph save "$figures/french_2ww_info1", replace


graph combine "$figures/french_2ww_mlp"  "$figures/french_2ww_mlp1" "$figures/french_2ww_info"   "$figures/french_2ww_info1"  , ycommon title("The share of French refugees during WWII, 10 categories") note("Vertical line indicates the Fact") graphregion(color(white))
graph save "$figures/figure_A5", replace
graph export "$figures/figure_A5.pdf", replace

erase "$figures/french_2ww_mlp.gph"  
erase "$figures/french_2ww_mlp1.gph" 
erase "$figures/french_2ww_info.gph"   
erase "$figures/french_2ww_info1.gph" 

**************************************************************************************************************************************************************************************
**** FIGURE A6 Generated in XLS from the literature review
**************************************************************************************************************************************************************************************

**************************************************************************************************************************************************************************************
**** FIGURE A7
**************************************************************************************************************************************************************************************

egen test_refug_men_mean=mean(test_refug_men), by(treatment opinion_unemp)

gen  test_labour_mig15_inv=11-test_labour_mig15

egen test_labour_mig15_inv_mean=mean(test_labour_mig15_inv), by(treatment opinion_unemp)

egen reason_migration_economic_mean=mean(test_labour_mig15_inv), by(treatment opinion_unemp)

preserve
drop if opinion_unemp>8

twoway (lowess test_refug_men_m opinion_unemp  if treatment==0, lpattern(solid) lwidth(medium)) || ///
		(lowess test_refug_men_m opinion_unemp  if treatment==1, lpattern(longdash) lwidth(medium)), ///
		legend(off)  title("Control vs. Alt-Facts") ytitle("Posterior") xtitle("Prior") ///
		xline(2) yline(6) xscale(r(1 8)) xla(1(1)8) yscale(range(5(1)9)) yla(5(1)9) scheme(s1mono)
		
graph save "$figures/prior_post_1", replace

twoway (lowess test_refug_men_m opinion_unemp  if treatment==0 , lpattern(solid) lwidth(medium)) || ///
		(lowess test_refug_men_m opinion_unemp  if treatment==2, lpattern(longdash_dot_dot) lwidth(medium) ///
		lcolor(gs1)), legend(off)  title("Control vs. Facts") ytitle("Posterior") xtitle("Prior") ///
		xline(2) yline(6) xscale(r(1 8)) xla(1(1)8) yscale(range(5(1)9)) yla(5(1)9) scheme(s1mono)
		
graph save "$figures/prior_post_2", replace

twoway (lowess test_refug_men_m opinion_unemp  if treatment==0 , lpattern(solid) lwidth(medium)) || ///
		(lowess test_refug_men_m opinion_unemp  if treatment==3, lpattern(shortdash) lwidth(medium)), ///
		legend(off)  title("Control vs. Fact-Check") ytitle("Posterior") xtitle("Prior") ///
		xline(2) yline(6) xscale(r(1 8)) xla(1(1)8) yscale(range(5(1)9)) yla(5(1)9) scheme(s1mono)
		
graph save "$figures/prior_post_3", replace

	* create blank variables in order to create common legend
	gen l_3 = .
	gen l_4 = . 
	
twoway (lowess test_refug_men_m opinion_unemp  if treatment==2, /// 1 = Facts
		lpattern(longdash_dot_dot) lwidth(medium) lcolor(gs1)) || ///
		(lowess test_refug_men_m opinion_unemp  if treatment==3, /// 2 = Fact-Check
		lpattern(shortdash) lwidth(medium)) || ///
		(lowess l_3 l_4  if treatment==0, /// 3 = Control
		lpattern(solid) lwidth(medium)) || ///
		(lowess  l_3 l_4  if treatment==1, /// 4 = Alt-Facts
		lpattern(longdash) lwidth(medium)),  title("Facts vs. Fact-Check") ytitle("Posterior") ///
		legend(order(3 4 1 2) label(1 "lowess for Facts") label(2 "lowess for Fact-Check") label(3 "lowess for Control") label(4 "lowess for Alt-Facts")) ///
		xtitle("Prior") xline(2) yline(6) xscale(r(1 8)) xla(1(1)8) yscale(range(5(1)9)) yla(5(1)9) scheme(s1mono)

graph save "$figures/prior_post_4", replace

grc1leg2  "$figures/prior_post_1"  "$figures/prior_post_3" "$figures/prior_post_2" "$figures/prior_post_4", ///
		ycommon title("Posterior on men among refugees vs." "Prior on unemployment rate among immigrants") ///
		note("Vertical and horizontal lines indicate the truth for prior and posterior, respectively.") scheme(s1mono) ///
		legendfrom("$figures/prior_post_4")
		
graph save "$figures/figure_A7", replace
graph export "$figures/figure_A7.pdf", replace

restore

erase "$figures/prior_post_1.gph"
erase "$figures/prior_post_2.gph"
erase "$figures/prior_post_3.gph"
erase "$figures/prior_post_4.gph"

**************************************************************************************************************************************************************************************
**** FIGURE A8
**************************************************************************************************************************************************************************************

preserve

drop if opinion_unemp>8

twoway (lowess test_labour_mig15_inv_m  opinion_unemp  if treatment==0 , ///
		lpattern(solid) lwidth(medium)) || (lowess test_labour_mig15_inv_m opinion_unemp ///
		if treatment==1, lpattern(longdash) lwidth(medium)), legend(off)  ///
		title("Control vs. Alt-Facts") ytitle("Posterior") xtitle("Prior") ///
		xline(2) yline(6) xscale(r(1 8)) xla(1(1)8) yscale(range(5(1)9)) yla(5(1)9) scheme(s1mono) 
graph save "$figures/prior_post_11", replace

twoway (lowess test_labour_mig15_inv_m  opinion_unemp  if treatment==0 , ///
		lpattern(solid) lwidth(medium)) || (lowess test_labour_mig15_inv_m opinion_unemp ///
		if treatment==2 , lpattern(longdash_dot_dot) lwidth(medium) lcolor(gs1)), ///
		legend(off)  title("Control vs. Facts") ytitle("Posterior") xtitle("Prior") ///
		xline(2) yline(6) xscale(r(1 8)) xla(1(1)8) yscale(range(5(1)9)) yla(5(1)9) scheme(s1mono)
		
graph save "$figures/prior_post_12", replace

twoway (lowess test_labour_mig15_inv_m  opinion_unemp  if treatment==0 , ///
		lpattern(solid) lwidth(medium)) || (lowess test_labour_mig15_inv_m opinion_unemp ///
		if treatment==3, lpattern(shortdash) lwidth(medium)), legend(off) ///
		title("Control vs. Fact-Check") ytitle("Posterior") xtitle("Prior") ///
		xline(2) yline(6)xscale(r(1 8)) xla(1(1)8) yscale(range(5(1)9)) yla(5(1)9) scheme(s1mono)
		
graph save "$figures/prior_post_13", replace
	
	* create blank variables in order to create common legend
	gen l_3 = .
	gen l_4 = . 
	
***** FOR LEGEND:
twoway (lowess l_3  l_4  if treatment==0 , ///
		lpattern(solid) lwidth(medium)) || ///
		(lowess l_3 l_4 if treatment==1, ///
		lpattern(longdash) lwidth(medium)) || ///
		(lowess test_labour_mig15_inv_m  opinion_unemp  if treatment==2 , ///
		lpattern(longdash_dot_dot) lwidth(medium) lcolor(gs1)) || ///
		(lowess test_labour_mig15_inv_m opinion_unemp  if treatment==3, ///
		lpattern(shortdash) lwidth(medium)),   title("Facts vs. Fact-Check") ///
		legend(label(1 "lowess for Control") label(2 "lowess for Alt-Facts") label(3 "lowess for Facts") label(4 "lowess for Fact-Check")) ///
		ytitle("Posterior") xtitle("Prior") xline(2) yline(6)  xla(1(1)8) yscale(range(5(1)9)) yla(5(1)9) scheme(s1mono)

		graph save "$figures/prior_post_14", replace

grc1leg  "$figures/prior_post_11"  "$figures/prior_post_13" ///
		"$figures/prior_post_12" "$figures/prior_post_14", ///
		ycommon title("Posterior on migrants not working vs." "Prior on unemployment rate among immigrants") ///
		note("Vertical and horizontal lines indicate the truth for prior and posterior, respectively.") ///
		scheme(s1mono) legendfrom("$figures/prior_post_14")
		
graph save "$figures/figure_A8", replace
graph export "$figures/figure_A8.pdf", replace

restore

erase "$figures/prior_post_11.gph"
erase "$figures/prior_post_12.gph"
erase "$figures/prior_post_13.gph"
erase "$figures/prior_post_14.gph"


**************************************************************************************************************************************************************************************
**** FIGURE A9 
**************************************************************************************************************************************************************************************
 
 
label define percent 1 "0-10" 2 "11-20" 3 "21-30" 4 "31-40" 5 "41-50" 6 "51-60" 7 "61-70" 8 "71-80"  9 "81-90" 10 "91-100"

label values test_refug_men percent
label values test_labour_mig15 percent
label values opinion_unemp percent

bysort test_refug_men: sum willvoteMLP if treatment==0
graph bar (mean) willvoteMLP if treatment==0&test_refug_men>1, ///
		over(test_refug_men, label(angle(50)))  ytitle("Will vote for MLP") ///
		title("% of men among refugees", color(black)) graphregion(color(white))
graph save "$figures/men_vote_bar", replace


bysort test_labour_mig15: sum willvoteMLP if treatment==0
graph bar (mean) willvoteMLP if treatment==0&test_labour_mig15<9, ///
		over(test_labour_mig15, label(angle(50))) ytitle("Will vote for MLP") ///
		title("% of migrants working", c(black)) graphregion(color(white))
graph save "$figures/working_vote_bar", replace


bysort opinion_unemp: sum willvoteMLP if treatment==0
graph bar (mean) willvoteMLP if treatment==0&opinion_unemp<9, ///
		over(opinion_unemp, label(angle(50))) ytitle("Will vote for MLP") ///
		 title("Unemployment rate among migrants", c(black)) graphregion(color(white))
graph save "$figures/prior_vote_bar", replace

graph combine "$figures/men_vote_bar"  "$figures/working_vote_bar" ///
		"$figures/prior_vote_bar", ycommon ///
		title("Voting intentions in control group" "as a function of factual beliefs", color(black))  graphregion(color(white))
		
graph save "$figures/figure_A9", replace
graph export "$figures/figure_A9.pdf", replace		


erase "$figures/men_vote_bar.gph"
erase "$figures/working_vote_bar.gph"
erase "$figures/prior_vote_bar.gph"
 
**************************************************************************************************************************************************************************************
**** FIGURE A10 on agree with MLP on immgration
**************************************************************************************************************************************************************************************

  
*label define percent 1 "0-10" 2 "11-20" 3 "21-30" 4 "31-40" 5 "41-50" 6 "51-60" 7 "61-70" 8 "71-80"  9 "81-90" 10 "91-100"

label values test_refug_men percent
label values test_labour_mig15 percent
label values opinion_unemp percent

bysort test_refug_men: sum agree if treatment==0
graph bar (mean) agree if treatment==0&test_refug_men>1, ///
		over(test_refug_men,  label(angle(50)))  ytitle("Agree with MLP on immigration") ///
		title("% of men among refugees", c(black))  graphregion(color(white))
graph save "$figures/men_agree_bar", replace


bysort test_labour_mig15: sum agree if treatment==0
graph bar (mean) agree if treatment==0&test_labour_mig15<9, ///
		over(test_labour_mig15,  label(angle(50))) ytitle("Agree with MLP on immigration") ///
		title("% of migrants working", c(black)) graphregion(color(white))
graph save "$figures/working_agree_bar", replace


bysort opinion_unemp: sum agree if treatment==0
graph bar (mean) agree if treatment==0&opinion_unemp<9, ///
		over(opinion_unemp,  label(angle(50))) ytitle("Agree with MLP on immigration") ///
		title("Unemployment rate among migrants", c(black)) graphregion(color(white))
graph save "$figures/prior_agree_bar", replace

graph combine "$figures/men_agree_bar"  "$figures/working_agree_bar" ///
		"$figures/prior_agree_bar", ycommon  ///
		title("Agree with MLP on immigration in control group" "as a function of factual beliefs", c(black))  ///
		graphregion(color(white))

graph save "$figures/figure_A10", replace
graph export "$figures/figure_A10.pdf", replace		

erase "$figures/men_agree_bar.gph"
erase "$figures/working_agree_bar.gph"
erase "$figures/prior_agree_bar.gph"


**************************************************************************************************************************************************************************************
**** FIGURE A11
**************************************************************************************************************************************************************************************

 
*label define percent 1 "0-10" 2 "11-20" 3 "21-30" 4 "31-40" 5 "41-50" 6 "51-60" 7 "61-70" 8 "71-80"  9 "81-90" 10 "91-100"

label values test_refug_men percent
label values test_labour_mig15 percent
label values opinion_unemp percent

bysort test_refug_men: sum reason_migration_economic if treatment==0
graph bar (mean) reason_migration_economic if treatment==0&test_refug_men>1, ///
		over(test_refug_men,  label(angle(50)))  ytitle("Reason to migrate economic") ///
		title("% of men among refugees", c(black))  graphregion(color(white))
graph save "$figures/men_reason_bar", replace


bysort test_labour_mig15: sum reason_migration_economic if treatment==0
graph bar (mean) reason_migration_economic if treatment==0&test_labour_mig15<9, ///
		over(test_labour_mig15,  label(angle(50))) ytitle("Reason to migrate economic") ///
		title("% of migrants working", c(black)) graphregion(color(white))
graph save "$figures/working_reason_bar", replace


bysort opinion_unemp: sum reason_migration_economic if treatment==0
graph bar (mean) reason_migration_economic if treatment==0&opinion_unemp<9, ///
		over(opinion_unemp,  label(angle(50))) ytitle("Reason to migrate economic") ///
		title("Unemployment rate among migrants", c(black)) graphregion(color(white))
graph save "$figures/prior_reason_bar", replace


graph combine "$figures/men_reason_bar"  "$figures/working_reason_bar" ///
		"$figures/prior_reason_bar", ycommon  ///
		title("Reason to migrate economic in control group" "as a function of factual beliefs", c(black))  ///
		graphregion(color(white))
		
graph save "$figures/figure_A11", replace
graph export "$figures/figure_A11.pdf", replace		
 
erase "$figures/men_reason_bar.gph"
erase "$figures/working_reason_bar.gph"
erase "$figures/prior_reason_bar.gph"

